#!/usr/bin/env python
"""
The most simple prompt example.
"""

from prompt_toolkit import prompt

if __name__ == "__main__":
    answer = prompt("Give me some input: ")
    print(f"You said: {answer}")



#!/usr/bin/env python
"""
Example of multiple individual completers that are combined into one.
"""

from prompt_toolkit import prompt
from prompt_toolkit.completion import WordCompleter, merge_completers

animal_completer = WordCompleter(
    [
        "alligator",
        "ant",
        "ape",
        "bat",
        "bear",
        "beaver",
        "bee",
        "bison",
        "butterfly",
        "cat",
        "chicken",
        "crocodile",
        "dinosaur",
        "dog",
        "dolphin",
        "dove",
        "duck",
        "eagle",
        "elephant",
        "fish",
        "goat",
        "gorilla",
        "kangaroo",
        "leopard",
        "lion",
        "mouse",
        "rabbit",
        "rat",
        "snake",
        "spider",
        "turkey",
        "turtle",
    ],
    ignore_case=True,
)

color_completer = WordCompleter(
    [
        "red",
        "green",
        "blue",
        "yellow",
        "white",
        "black",
        "orange",
        "gray",
        "pink",
        "purple",
        "cyan",
        "magenta",
        "violet",
    ],
    ignore_case=True,
)


def main():
    completer = merge_completers([animal_completer, color_completer])

    text = prompt(
        "Give some animals: ", completer=completer, complete_while_typing=False
    )
    print(f"You said: {text}")


if __name__ == "__main__":
    main()



#!/usr/bin/env python
"""
A simple Telnet application that asks for input and responds.

The interaction function is a prompt_toolkit coroutine.
Also see the `hello-world-asyncio.py` example which uses an asyncio coroutine.
That is probably the preferred way if you only need Python 3 support.
"""

import logging
from asyncio import run

from prompt_toolkit.contrib.telnet.server import TelnetServer
from prompt_toolkit.shortcuts import PromptSession, clear

# Set up logging
logging.basicConfig()
logging.getLogger().setLevel(logging.INFO)


async def interact(connection):
    clear()
    connection.send("Welcome!\n")

    # Ask for input.
    session = PromptSession()
    result = await session.prompt_async(message="Say something: ")

    # Send output.
    connection.send(f"You said: {result}\n")
    connection.send("Bye.\n")


async def main():
    server = TelnetServer(interact=interact, port=2323)
    await server.run()


if __name__ == "__main__":
    run(main())
